from near_jsonrpc_models.internal_error import InternalError
from near_jsonrpc_models.rpc_block_error import RpcBlockError
from near_jsonrpc_models.rpc_request_validation_error_kind import RpcRequestValidationErrorKind
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class ErrorWrapperForRpcBlockErrorRequestValidationError(BaseModel):
    cause: RpcRequestValidationErrorKind
    name: Literal['REQUEST_VALIDATION_ERROR']

class ErrorWrapperForRpcBlockErrorHandlerError(BaseModel):
    cause: RpcBlockError
    name: Literal['HANDLER_ERROR']

class ErrorWrapperForRpcBlockErrorInternalError(BaseModel):
    cause: InternalError
    name: Literal['INTERNAL_ERROR']

class ErrorWrapperForRpcBlockError(RootModel[Union[ErrorWrapperForRpcBlockErrorRequestValidationError, ErrorWrapperForRpcBlockErrorHandlerError, ErrorWrapperForRpcBlockErrorInternalError]]):
    pass




from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.block_header_view import BlockHeaderView
from near_jsonrpc_models.chunk_header_view import ChunkHeaderView
from pydantic import BaseModel
from typing import List


class RpcBlockResponse(BaseModel):
    # The AccountId of the author of the Block
    author: AccountId
    chunks: List[ChunkHeaderView]
    header: BlockHeaderView



"""Configures how to dump state to external storage."""

from near_jsonrpc_models.duration_as_std_schema_provider import DurationAsStdSchemaProvider
from near_jsonrpc_models.external_storage_location import ExternalStorageLocation
from near_jsonrpc_models.shard_id import ShardId
from pydantic import BaseModel
from typing import List


class DumpConfig(BaseModel):
    # Location of a json file with credentials allowing access to the bucket.
    credentials_file: str | None = None
    # How often to check if a new epoch has started.
    # Feel free to set to `None`, defaults are sensible.
    iteration_delay: DurationAsStdSchemaProvider | None = None
    # Specifies where to write the obtained state parts.
    location: ExternalStorageLocation = None
    # Use in case a node that dumps state to the external storage
    # gets in trouble.
    restart_dump_for_shards: List[ShardId] | None = None



from near_jsonrpc_models.internal_error import InternalError
from near_jsonrpc_models.rpc_receipt_error import RpcReceiptError
from near_jsonrpc_models.rpc_request_validation_error_kind import RpcRequestValidationErrorKind
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class ErrorWrapperForRpcReceiptErrorRequestValidationError(BaseModel):
    cause: RpcRequestValidationErrorKind
    name: Literal['REQUEST_VALIDATION_ERROR']

class ErrorWrapperForRpcReceiptErrorHandlerError(BaseModel):
    cause: RpcReceiptError
    name: Literal['HANDLER_ERROR']

class ErrorWrapperForRpcReceiptErrorInternalError(BaseModel):
    cause: InternalError
    name: Literal['INTERNAL_ERROR']

class ErrorWrapperForRpcReceiptError(RootModel[Union[ErrorWrapperForRpcReceiptErrorRequestValidationError, ErrorWrapperForRpcReceiptErrorHandlerError, ErrorWrapperForRpcReceiptErrorInternalError]]):
    pass




"""A list of shard's bandwidth requests.
Describes how much the shard would like to send to other shards."""

from near_jsonrpc_models.bandwidth_requests_v1 import BandwidthRequestsV1
from near_jsonrpc_models.strict_model import StrictBaseModel
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class BandwidthRequestsV1Option(StrictBaseModel):
    V1: BandwidthRequestsV1

class BandwidthRequests(RootModel[Union[BandwidthRequestsV1Option]]):
    pass




"""Configuration for a cloud-based archival writer. If this config is present, the writer is enabled and
writes chunk-related data based on the tracked shards. This config also controls additional archival
behavior such as block data and polling interval."""

from near_jsonrpc_models.duration_as_std_schema_provider import DurationAsStdSchemaProvider
from pydantic import BaseModel
from pydantic import Field


class CloudArchivalWriterConfig(BaseModel):
    # Determines whether block-related data should be written to cloud storage.
    archive_block_data: bool = False
    # Interval at which the system checks for new blocks or chunks to archive.
    polling_interval: DurationAsStdSchemaProvider = Field(default_factory=lambda: DurationAsStdSchemaProvider(**{'nanos': 0, 'secs': 1}))



"""Height and hash of a block"""

from near_jsonrpc_models.crypto_hash import CryptoHash
from pydantic import BaseModel
from pydantic import conint


class BlockStatusView(BaseModel):
    hash: CryptoHash
    height: conint(ge=0, le=18446744073709551615)



from near_jsonrpc_models.internal_error import InternalError
from near_jsonrpc_models.rpc_request_validation_error_kind import RpcRequestValidationErrorKind
from near_jsonrpc_models.rpc_view_state_error import RpcViewStateError
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class ErrorWrapperForRpcViewStateErrorRequestValidationError(BaseModel):
    cause: RpcRequestValidationErrorKind
    name: Literal['REQUEST_VALIDATION_ERROR']

class ErrorWrapperForRpcViewStateErrorHandlerError(BaseModel):
    cause: RpcViewStateError
    name: Literal['HANDLER_ERROR']

class ErrorWrapperForRpcViewStateErrorInternalError(BaseModel):
    cause: InternalError
    name: Literal['INTERNAL_ERROR']

class ErrorWrapperForRpcViewStateError(RootModel[Union[ErrorWrapperForRpcViewStateErrorRequestValidationError, ErrorWrapperForRpcViewStateErrorHandlerError, ErrorWrapperForRpcViewStateErrorInternalError]]):
    pass




"""The result of splitting a memtrie into two possibly even parts, according to `memory_usage`
stored in the trie nodes.

**NOTE: This is an artificial value calculated according to `TRIE_COST`. Hence, it does not
represent actual memory allocation, but the split ratio should be roughly consistent with that.**"""

from near_jsonrpc_models.account_id import AccountId
from pydantic import BaseModel
from pydantic import conint


class TrieSplit(BaseModel):
    # Account ID representing the split path
    boundary_account: AccountId
    # Total `memory_usage` of the left part (excluding the split path)
    left_memory: conint(ge=0, le=18446744073709551615)
    # Total `memory_usage` of the right part (including the split path)
    right_memory: conint(ge=0, le=18446744073709551615)



"""Stores the congestion level of a shard. More info about congestion [here](https://near.github.io/nearcore/architecture/how/receipt-congestion.html?highlight=congestion#receipt-congestion)"""

from pydantic import BaseModel
from pydantic import conint


class CongestionInfoView(BaseModel):
    allowed_shard: conint(ge=0, le=65535)
    buffered_receipts_gas: str
    delayed_receipts_gas: str
    receipt_bytes: conint(ge=0, le=18446744073709551615)



from near_jsonrpc_models.error_wrapper_for_rpc_light_client_proof_error import ErrorWrapperForRpcLightClientProofError
from near_jsonrpc_models.rpc_light_client_block_proof_response import RpcLightClientBlockProofResponse
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class JsonRpcResponseForRpcLightClientBlockProofResponseAndRpcLightClientProofErrorResult(BaseModel):
    id: str
    jsonrpc: str
    result: RpcLightClientBlockProofResponse

class JsonRpcResponseForRpcLightClientBlockProofResponseAndRpcLightClientProofErrorError(BaseModel):
    id: str
    jsonrpc: str
    error: ErrorWrapperForRpcLightClientProofError

class JsonRpcResponseForRpcLightClientBlockProofResponseAndRpcLightClientProofError(RootModel[Union[JsonRpcResponseForRpcLightClientBlockProofResponseAndRpcLightClientProofErrorResult, JsonRpcResponseForRpcLightClientBlockProofResponseAndRpcLightClientProofErrorError]]):
    pass




"""Gas key nonces view returned by the `view_gas_key_nonces` RPC query."""

from pydantic import BaseModel
from pydantic import conint
from typing import List


class GasKeyNoncesView(BaseModel):
    nonces: List[conint(ge=0, le=18446744073709551615)]



"""The structure describes configuration for creation of new accounts."""

from near_jsonrpc_models.account_id import AccountId
from pydantic import BaseModel
from pydantic import conint


class AccountCreationConfigView(BaseModel):
    # The minimum length of the top-level account ID that is allowed to be created by any account.
    min_allowed_top_level_account_length: conint(ge=0, le=255) = None
    # The account ID of the account registrar. This account ID allowed to create top-level
    # accounts of any valid length.
    registrar_account_id: AccountId = None



"""Describes different fees for the runtime"""

from near_jsonrpc_models.action_creation_config_view import ActionCreationConfigView
from near_jsonrpc_models.data_receipt_creation_config_view import DataReceiptCreationConfigView
from near_jsonrpc_models.fee import Fee
from near_jsonrpc_models.storage_usage_config_view import StorageUsageConfigView
from pydantic import BaseModel
from pydantic import conint
from pydantic import conlist
from typing import List


class RuntimeFeesConfigView(BaseModel):
    # Describes the cost of creating a certain action, `Action`. Includes all variants.
    action_creation_config: ActionCreationConfigView = None
    # Describes the cost of creating an action receipt, `ActionReceipt`, excluding the actual cost
    # of actions.
    # - `send` cost is burned when a receipt is created using `promise_create` or
    #     `promise_batch_create`
    # - `exec` cost is burned when the receipt is being executed.
    action_receipt_creation_config: Fee = None
    # Fraction of the burnt gas to reward to the contract account for execution.
    burnt_gas_reward: conlist(conint(ge=-2147483648, le=2147483647), min_length=2, max_length=2) = None
    # Describes the cost of creating a data receipt, `DataReceipt`.
    data_receipt_creation_config: DataReceiptCreationConfigView = None
    # Pessimistic gas price inflation ratio.
    pessimistic_gas_price_inflation_ratio: conlist(conint(ge=-2147483648, le=2147483647), min_length=2, max_length=2) = None
    # Describes fees for storage.
    storage_usage_config: StorageUsageConfigView = None



"""Withdraw NEAR from a gas key's balance to the account.

This action must only be available via transactions, not via contract execution
(there is no corresponding promise batch action host function)."""

from near_jsonrpc_models.near_token import NearToken
from near_jsonrpc_models.public_key import PublicKey
from pydantic import BaseModel


class WithdrawFromGasKeyAction(BaseModel):
    # Amount of NEAR to transfer from the gas key
    amount: NearToken
    # The public key of the gas key to withdraw from
    public_key: PublicKey



from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.block_id import BlockId
from near_jsonrpc_models.finality import Finality
from near_jsonrpc_models.sync_checkpoint import SyncCheckpoint
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class RpcViewCodeRequestBlockId(BaseModel):
    account_id: AccountId
    block_id: BlockId

class RpcViewCodeRequestFinality(BaseModel):
    account_id: AccountId
    finality: Finality

class RpcViewCodeRequestSyncCheckpoint(BaseModel):
    account_id: AccountId
    sync_checkpoint: SyncCheckpoint

class RpcViewCodeRequest(RootModel[Union[RpcViewCodeRequestBlockId, RpcViewCodeRequestFinality, RpcViewCodeRequestSyncCheckpoint]]):
    pass




from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.action_view import ActionView
from near_jsonrpc_models.crypto_hash import CryptoHash
from near_jsonrpc_models.data_receiver_view import DataReceiverView
from near_jsonrpc_models.global_contract_identifier import GlobalContractIdentifier
from near_jsonrpc_models.near_token import NearToken
from near_jsonrpc_models.public_key import PublicKey
from near_jsonrpc_models.shard_id import ShardId
from near_jsonrpc_models.strict_model import StrictBaseModel
from pydantic import BaseModel
from pydantic import RootModel
from pydantic import conint
from typing import List
from typing import Union


class ReceiptEnumViewActionPayload(BaseModel):
    actions: List[ActionView]
    gas_price: NearToken
    input_data_ids: List[CryptoHash]
    is_promise_yield: bool = False
    output_data_receivers: List[DataReceiverView]
    refund_to: AccountId | None = None
    signer_id: AccountId
    signer_public_key: PublicKey

class ReceiptEnumViewAction(StrictBaseModel):
    Action: ReceiptEnumViewActionPayload

class ReceiptEnumViewDataPayload(BaseModel):
    data: str | None = None
    data_id: CryptoHash
    is_promise_resume: bool = False

class ReceiptEnumViewData(StrictBaseModel):
    Data: ReceiptEnumViewDataPayload

class ReceiptEnumViewGlobalContractDistributionPayload(BaseModel):
    already_delivered_shards: List[ShardId]
    code: str
    id: GlobalContractIdentifier
    nonce: conint(ge=0, le=18446744073709551615) | None = None
    target_shard: ShardId

class ReceiptEnumViewGlobalContractDistribution(StrictBaseModel):
    GlobalContractDistribution: ReceiptEnumViewGlobalContractDistributionPayload

class ReceiptEnumView(RootModel[Union[ReceiptEnumViewAction, ReceiptEnumViewData, ReceiptEnumViewGlobalContractDistribution]]):
    pass




"""Describes access key permission scope and nonce."""

from near_jsonrpc_models.access_key_permission_view import AccessKeyPermissionView
from pydantic import BaseModel
from pydantic import conint


class AccessKeyView(BaseModel):
    nonce: conint(ge=0, le=18446744073709551615)
    permission: AccessKeyPermissionView



from near_jsonrpc_models.cost_gas_used import CostGasUsed
from pydantic import BaseModel
from pydantic import conint
from typing import List


class ExecutionMetadataView(BaseModel):
    gas_profile: List[CostGasUsed] | None = None
    version: conint(ge=0, le=4294967295)



"""Describes cost of storage per block"""

from pydantic import BaseModel
from pydantic import conint


class StorageUsageConfigView(BaseModel):
    # Number of bytes for an account record, including rounding up for account id.
    num_bytes_account: conint(ge=0, le=18446744073709551615) = None
    # Additional number of bytes for a k/v record
    num_extra_bytes_record: conint(ge=0, le=18446744073709551615) = None



"""Contains the split storage information."""

from pydantic import BaseModel
from pydantic import conint


class RpcSplitStorageInfoResponse(BaseModel):
    cold_head_height: conint(ge=0, le=18446744073709551615) | None = None
    final_head_height: conint(ge=0, le=18446744073709551615) | None = None
    head_height: conint(ge=0, le=18446744073709551615) | None = None
    hot_db_kind: str | None = None



"""Access key provides limited access to an account. Each access key belongs to some account and
is identified by a unique (within the account) public key. One account may have large number of
access keys. Access keys allow to act on behalf of the account by restricting transactions
that can be issued.
`account_id,public_key` is a key in the state"""

from near_jsonrpc_models.access_key_permission import AccessKeyPermission
from pydantic import BaseModel
from pydantic import conint


class AccessKey(BaseModel):
    # Nonce for this access key, used for tx nonce generation. When access key is created, nonce
    # is set to `(block_height - 1) * 1e6` to avoid tx hash collision on access key re-creation.
    # See <https://github.com/near/nearcore/issues/3779> for more details.
    nonce: conint(ge=0, le=18446744073709551615)
    # Defines permissions for this access key.
    permission: AccessKeyPermission



"""Contexts in which `StorageError::MissingTrieValue` error might occur.TrieIterator: Missing trie value when reading from TrieIterator.TriePrefetchingStorage: Missing trie value when reading from TriePrefetchingStorage.TrieMemoryPartialStorage: Missing trie value when reading from TrieMemoryPartialStorage.TrieStorage: Missing trie value when reading from TrieStorage."""

from pydantic import RootModel
from typing import Literal


class MissingTrieValueContext(RootModel[Literal['TrieIterator', 'TriePrefetchingStorage', 'TrieMemoryPartialStorage', 'TrieStorage']]):
    pass




from near_jsonrpc_models.genesis_config_error import GenesisConfigError
from near_jsonrpc_models.internal_error import InternalError
from near_jsonrpc_models.rpc_request_validation_error_kind import RpcRequestValidationErrorKind
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class ErrorWrapperForGenesisConfigErrorRequestValidationError(BaseModel):
    cause: RpcRequestValidationErrorKind
    name: Literal['REQUEST_VALIDATION_ERROR']

class ErrorWrapperForGenesisConfigErrorHandlerError(BaseModel):
    cause: GenesisConfigError
    name: Literal['HANDLER_ERROR']

class ErrorWrapperForGenesisConfigErrorInternalError(BaseModel):
    cause: InternalError
    name: Literal['INTERNAL_ERROR']

class ErrorWrapperForGenesisConfigError(RootModel[Union[ErrorWrapperForGenesisConfigErrorRequestValidationError, ErrorWrapperForGenesisConfigErrorHandlerError, ErrorWrapperForGenesisConfigErrorInternalError]]):
    pass




from near_jsonrpc_models.rpc_health_request import RpcHealthRequest
from pydantic import BaseModel
from typing import Literal


class JsonRpcRequestForHealth(BaseModel):
    id: str
    jsonrpc: str
    method: Literal['health']
    params: RpcHealthRequest



from near_jsonrpc_models.rpc_transaction_status_request import RpcTransactionStatusRequest
from pydantic import BaseModel
from typing import Literal


class JsonRpcRequestForExperimentalTxStatus(BaseModel):
    id: str
    jsonrpc: str
    method: Literal['EXPERIMENTAL_tx_status']
    params: RpcTransactionStatusRequest



"""A state for the current head of a light client. More info [here](https://nomicon.io/ChainSpec/LightClient)."""

from near_jsonrpc_models.block_header_inner_lite_view import BlockHeaderInnerLiteView
from near_jsonrpc_models.crypto_hash import CryptoHash
from near_jsonrpc_models.signature import Signature
from near_jsonrpc_models.validator_stake_view import ValidatorStakeView
from pydantic import BaseModel
from typing import List


class RpcLightClientNextBlockResponse(BaseModel):
    approvals_after_next: List[Signature | None] = None
    # Inner part of the block header that gets hashed, split into two parts, one that is sent
    #    to light clients, and the rest
    inner_lite: BlockHeaderInnerLiteView = None
    inner_rest_hash: CryptoHash = None
    next_block_inner_hash: CryptoHash = None
    next_bps: List[ValidatorStakeView] | None = None
    prev_block_hash: CryptoHash = None



from pydantic import BaseModel
from pydantic import RootModel
from typing import Any
from typing import Dict
from typing import Literal
from typing import Union


class RpcProtocolConfigErrorUnknownBlock(BaseModel):
    info: Dict[str, Any]
    name: Literal['UNKNOWN_BLOCK']

class RpcProtocolConfigErrorInternalErrorInfo(BaseModel):
    error_message: str

class RpcProtocolConfigErrorInternalError(BaseModel):
    info: RpcProtocolConfigErrorInternalErrorInfo
    name: Literal['INTERNAL_ERROR']

class RpcProtocolConfigError(RootModel[Union[RpcProtocolConfigErrorUnknownBlock, RpcProtocolConfigErrorInternalError]]):
    pass




"""Deploy global contract action"""

from near_jsonrpc_models.global_contract_deploy_mode import GlobalContractDeployMode
from pydantic import BaseModel


class DeployGlobalContractAction(BaseModel):
    # WebAssembly binary
    code: str
    deploy_mode: GlobalContractDeployMode



from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.function_call_error import FunctionCallError
from near_jsonrpc_models.global_contract_identifier import GlobalContractIdentifier
from near_jsonrpc_models.invalid_access_key_error import InvalidAccessKeyError
from near_jsonrpc_models.near_token import NearToken
from near_jsonrpc_models.public_key import PublicKey
from near_jsonrpc_models.receipt_validation_error import ReceiptValidationError
from near_jsonrpc_models.strict_model import StrictBaseModel
from pydantic import BaseModel
from pydantic import RootModel
from pydantic import conint
from typing import Literal
from typing import Union


class ActionErrorKindAccountAlreadyExistsPayload(BaseModel):
    account_id: AccountId

class ActionErrorKindAccountAlreadyExists(StrictBaseModel):
    """Happens when CreateAccount action tries to create an account with account_id which is already exists in the storage"""
    AccountAlreadyExists: ActionErrorKindAccountAlreadyExistsPayload

class ActionErrorKindAccountDoesNotExistPayload(BaseModel):
    account_id: AccountId

class ActionErrorKindAccountDoesNotExist(StrictBaseModel):
    """Happens when TX receiver_id doesn't exist (but action is not Action::CreateAccount)"""
    AccountDoesNotExist: ActionErrorKindAccountDoesNotExistPayload

class ActionErrorKindCreateAccountOnlyByRegistrarPayload(BaseModel):
    account_id: AccountId
    predecessor_id: AccountId
    registrar_account_id: AccountId

class ActionErrorKindCreateAccountOnlyByRegistrar(StrictBaseModel):
    """A top-level account ID can only be created by registrar."""
    CreateAccountOnlyByRegistrar: ActionErrorKindCreateAccountOnlyByRegistrarPayload

class ActionErrorKindCreateAccountNotAllowedPayload(BaseModel):
    account_id: AccountId
    predecessor_id: AccountId

class ActionErrorKindCreateAccountNotAllowed(StrictBaseModel):
    """A newly created account must be under a namespace of the creator account"""
    CreateAccountNotAllowed: ActionErrorKindCreateAccountNotAllowedPayload

class ActionErrorKindActorNoPermissionPayload(BaseModel):
    account_id: AccountId
    actor_id: AccountId

class ActionErrorKindActorNoPermission(StrictBaseModel):
    """Administrative actions like `DeployContract`, `Stake`, `AddKey`, `DeleteKey`. can be proceed only if sender=receiver
or the first TX action is a `CreateAccount` action"""
    ActorNoPermission: ActionErrorKindActorNoPermissionPayload

class ActionErrorKindDeleteKeyDoesNotExistPayload(BaseModel):
    account_id: AccountId
    public_key: PublicKey

class ActionErrorKindDeleteKeyDoesNotExist(StrictBaseModel):
    """Account tries to remove an access key that doesn't exist"""
    DeleteKeyDoesNotExist: ActionErrorKindDeleteKeyDoesNotExistPayload

class ActionErrorKindAddKeyAlreadyExistsPayload(BaseModel):
    account_id: AccountId
    public_key: PublicKey

class ActionErrorKindAddKeyAlreadyExists(StrictBaseModel):
    """The public key is already used for an existing access key"""
    AddKeyAlreadyExists: ActionErrorKindAddKeyAlreadyExistsPayload

class ActionErrorKindDeleteAccountStakingPayload(BaseModel):
    account_id: AccountId

class ActionErrorKindDeleteAccountStaking(StrictBaseModel):
    """Account is staking and can not be deleted"""
    DeleteAccountStaking: ActionErrorKindDeleteAccountStakingPayload

class ActionErrorKindLackBalanceForStatePayload(BaseModel):
    # An account which needs balance
    account_id: AccountId
    # Balance required to complete an action.
    amount: NearToken

class ActionErrorKindLackBalanceForState(StrictBaseModel):
    """ActionReceipt can't be completed, because the remaining balance will not be enough to cover storage."""
    LackBalanceForState: ActionErrorKindLackBalanceForStatePayload

class ActionErrorKindTriesToUnstakePayload(BaseModel):
    account_id: AccountId

class ActionErrorKindTriesToUnstake(StrictBaseModel):
    """Account is not yet staked, but tries to unstake"""
    TriesToUnstake: ActionErrorKindTriesToUnstakePayload

class ActionErrorKindTriesToStakePayload(BaseModel):
    account_id: AccountId
    balance: NearToken
    locked: NearToken
    stake: NearToken

class ActionErrorKindTriesToStake(StrictBaseModel):
    """The account doesn't have enough balance to increase the stake."""
    TriesToStake: ActionErrorKindTriesToStakePayload

class ActionErrorKindInsufficientStakePayload(BaseModel):
    account_id: AccountId
    minimum_stake: NearToken
    stake: NearToken

class ActionErrorKindInsufficientStake(StrictBaseModel):
    InsufficientStake: ActionErrorKindInsufficientStakePayload

class ActionErrorKindFunctionCallError(StrictBaseModel):
    """An error occurred during a `FunctionCall` Action, parameter is debug message."""
    FunctionCallError: FunctionCallError

class ActionErrorKindNewReceiptValidationError(StrictBaseModel):
    """Error occurs when a new `ActionReceipt` created by the `FunctionCall` action fails
receipt validation."""
    NewReceiptValidationError: ReceiptValidationError

class ActionErrorKindOnlyImplicitAccountCreationAllowedPayload(BaseModel):
    account_id: AccountId

class ActionErrorKindOnlyImplicitAccountCreationAllowed(StrictBaseModel):
    """Error occurs when a `CreateAccount` action is called on a NEAR-implicit or ETH-implicit account.
See NEAR-implicit account creation NEP: <https://github.com/nearprotocol/NEPs/pull/71>.
Also, see ETH-implicit account creation NEP: <https://github.com/near/NEPs/issues/518>.

TODO(#8598): This error is named very poorly. A better name would be
`OnlyNamedAccountCreationAllowed`."""
    OnlyImplicitAccountCreationAllowed: ActionErrorKindOnlyImplicitAccountCreationAllowedPayload

class ActionErrorKindDeleteAccountWithLargeStatePayload(BaseModel):
    account_id: AccountId

class ActionErrorKindDeleteAccountWithLargeState(StrictBaseModel):
    """Delete account whose state is large is temporarily banned."""
    DeleteAccountWithLargeState: ActionErrorKindDeleteAccountWithLargeStatePayload

"""Signature does not match the provided actions and given signer public key."""
class ActionErrorKindDelegateActionInvalidSignature(RootModel[Literal['DelegateActionInvalidSignature']]):
    pass

class ActionErrorKindDelegateActionSenderDoesNotMatchTxReceiverPayload(BaseModel):
    receiver_id: AccountId
    sender_id: AccountId

class ActionErrorKindDelegateActionSenderDoesNotMatchTxReceiver(StrictBaseModel):
    """Receiver of the transaction doesn't match Sender of the delegate action"""
    DelegateActionSenderDoesNotMatchTxReceiver: ActionErrorKindDelegateActionSenderDoesNotMatchTxReceiverPayload

"""Delegate action has expired. `max_block_height` is less than actual block height."""
class ActionErrorKindDelegateActionExpired(RootModel[Literal['DelegateActionExpired']]):
    pass

class ActionErrorKindDelegateActionAccessKeyError(StrictBaseModel):
    """The given public key doesn't exist for Sender account"""
    DelegateActionAccessKeyError: InvalidAccessKeyError

class ActionErrorKindDelegateActionInvalidNoncePayload(BaseModel):
    ak_nonce: conint(ge=0, le=18446744073709551615)
    delegate_nonce: conint(ge=0, le=18446744073709551615)

class ActionErrorKindDelegateActionInvalidNonce(StrictBaseModel):
    """DelegateAction nonce must be greater sender[public_key].nonce"""
    DelegateActionInvalidNonce: ActionErrorKindDelegateActionInvalidNoncePayload

class ActionErrorKindDelegateActionNonceTooLargePayload(BaseModel):
    delegate_nonce: conint(ge=0, le=18446744073709551615)
    upper_bound: conint(ge=0, le=18446744073709551615)

class ActionErrorKindDelegateActionNonceTooLarge(StrictBaseModel):
    """DelegateAction nonce is larger than the upper bound given by the block height"""
    DelegateActionNonceTooLarge: ActionErrorKindDelegateActionNonceTooLargePayload

class ActionErrorKindGlobalContractDoesNotExistPayload(BaseModel):
    identifier: GlobalContractIdentifier

class ActionErrorKindGlobalContractDoesNotExist(StrictBaseModel):
    GlobalContractDoesNotExist: ActionErrorKindGlobalContractDoesNotExistPayload

class ActionErrorKindGasKeyDoesNotExistPayload(BaseModel):
    account_id: AccountId
    public_key: PublicKey

class ActionErrorKindGasKeyDoesNotExist(StrictBaseModel):
    """Gas key does not exist for the specified public key"""
    GasKeyDoesNotExist: ActionErrorKindGasKeyDoesNotExistPayload

class ActionErrorKindInsufficientGasKeyBalancePayload(BaseModel):
    account_id: AccountId
    balance: NearToken
    public_key: PublicKey
    required: NearToken

class ActionErrorKindInsufficientGasKeyBalance(StrictBaseModel):
    """Gas key does not have sufficient balance for the requested withdrawal"""
    InsufficientGasKeyBalance: ActionErrorKindInsufficientGasKeyBalancePayload

class ActionErrorKindGasKeyBalanceTooHighPayload(BaseModel):
    account_id: AccountId
    balance: NearToken
    # Set for DeleteKey (specific key), None for DeleteAccount (aggregate)
    public_key: PublicKey | None = None

class ActionErrorKindGasKeyBalanceTooHigh(StrictBaseModel):
    """Gas key balance is too high to burn during deletion"""
    GasKeyBalanceTooHigh: ActionErrorKindGasKeyBalanceTooHighPayload

class ActionErrorKind(RootModel[Union[ActionErrorKindAccountAlreadyExists, ActionErrorKindAccountDoesNotExist, ActionErrorKindCreateAccountOnlyByRegistrar, ActionErrorKindCreateAccountNotAllowed, ActionErrorKindActorNoPermission, ActionErrorKindDeleteKeyDoesNotExist, ActionErrorKindAddKeyAlreadyExists, ActionErrorKindDeleteAccountStaking, ActionErrorKindLackBalanceForState, ActionErrorKindTriesToUnstake, ActionErrorKindTriesToStake, ActionErrorKindInsufficientStake, ActionErrorKindFunctionCallError, ActionErrorKindNewReceiptValidationError, ActionErrorKindOnlyImplicitAccountCreationAllowed, ActionErrorKindDeleteAccountWithLargeState, ActionErrorKindDelegateActionInvalidSignature, ActionErrorKindDelegateActionSenderDoesNotMatchTxReceiver, ActionErrorKindDelegateActionExpired, ActionErrorKindDelegateActionAccessKeyError, ActionErrorKindDelegateActionInvalidNonce, ActionErrorKindDelegateActionNonceTooLarge, ActionErrorKindGlobalContractDoesNotExist, ActionErrorKindGasKeyDoesNotExist, ActionErrorKindInsufficientGasKeyBalance, ActionErrorKindGasKeyBalanceTooHigh]]):
    pass




from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.block_id import BlockId
from near_jsonrpc_models.finality import Finality
from near_jsonrpc_models.function_args import FunctionArgs
from near_jsonrpc_models.sync_checkpoint import SyncCheckpoint
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class RpcCallFunctionRequestBlockId(BaseModel):
    account_id: AccountId
    args_base64: FunctionArgs
    method_name: str
    block_id: BlockId

class RpcCallFunctionRequestFinality(BaseModel):
    account_id: AccountId
    args_base64: FunctionArgs
    method_name: str
    finality: Finality

class RpcCallFunctionRequestSyncCheckpoint(BaseModel):
    account_id: AccountId
    args_base64: FunctionArgs
    method_name: str
    sync_checkpoint: SyncCheckpoint

class RpcCallFunctionRequest(RootModel[Union[RpcCallFunctionRequestBlockId, RpcCallFunctionRequestFinality, RpcCallFunctionRequestSyncCheckpoint]]):
    pass




from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.validator_kickout_reason import ValidatorKickoutReason
from pydantic import BaseModel


class ValidatorKickoutView(BaseModel):
    account_id: AccountId
    reason: ValidatorKickoutReason



from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.crypto_hash import CryptoHash
from near_jsonrpc_models.execution_metadata_view import ExecutionMetadataView
from near_jsonrpc_models.execution_status_view import ExecutionStatusView
from near_jsonrpc_models.near_gas import NearGas
from near_jsonrpc_models.near_token import NearToken
from pydantic import BaseModel
from pydantic import Field
from typing import List


class ExecutionOutcomeView(BaseModel):
    # The id of the account on which the execution happens. For transaction this is signer_id,
    # for receipt this is receiver_id.
    executor_id: AccountId
    # The amount of the gas burnt by the given transaction or receipt.
    gas_burnt: NearGas
    # Logs from this transaction or receipt.
    logs: List[str]
    # Execution metadata, versioned
    metadata: ExecutionMetadataView = Field(default_factory=lambda: ExecutionMetadataView(**{'version': 1}))
    # Receipt IDs generated by this transaction or receipt.
    receipt_ids: List[CryptoHash]
    # Execution status. Contains the result in case of successful execution.
    status: ExecutionStatusView
    # The amount of tokens burnt corresponding to the burnt gas amount.
    # This value doesn't always equal to the `gas_burnt` multiplied by the gas price, because
    # the prepaid gas price might be lower than the actual gas price and it creates a deficit.
    # `tokens_burnt` also contains the penalty subtracted from refunds, while
    # `gas_burnt` only contains the gas that we actually burn for the execution.
    tokens_burnt: NearToken



"""Serializable version of `near-vm-runner::FunctionCallError`.

Must never reorder/remove elements, can only add new variants at the end (but do that very
carefully). It describes stable serialization format, and only used by serialization logic."""

from near_jsonrpc_models.compilation_error import CompilationError
from near_jsonrpc_models.host_error import HostError
from near_jsonrpc_models.method_resolve_error import MethodResolveError
from near_jsonrpc_models.strict_model import StrictBaseModel
from near_jsonrpc_models.wasm_trap import WasmTrap
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class FunctionCallErrorWasmUnknownError(RootModel[Literal['WasmUnknownError', '_EVMError']]):
    pass

class FunctionCallErrorCompilationError(StrictBaseModel):
    """Wasm compilation error"""
    CompilationError: CompilationError

class FunctionCallErrorLinkErrorPayload(BaseModel):
    msg: str

class FunctionCallErrorLinkError(StrictBaseModel):
    """Wasm binary env link error

Note: this is only to deserialize old data, use execution error for new data"""
    LinkError: FunctionCallErrorLinkErrorPayload

class FunctionCallErrorMethodResolveError(StrictBaseModel):
    """Import/export resolve error"""
    MethodResolveError: MethodResolveError

class FunctionCallErrorWasmTrap(StrictBaseModel):
    """A trap happened during execution of a binary

Note: this is only to deserialize old data, use execution error for new data"""
    WasmTrap: WasmTrap

class FunctionCallErrorHostError(StrictBaseModel):
    """Note: this is only to deserialize old data, use execution error for new data"""
    HostError: HostError

class FunctionCallErrorExecutionError(StrictBaseModel):
    ExecutionError: str

class FunctionCallError(RootModel[Union[FunctionCallErrorWasmUnknownError, FunctionCallErrorCompilationError, FunctionCallErrorLinkError, FunctionCallErrorMethodResolveError, FunctionCallErrorWasmTrap, FunctionCallErrorHostError, FunctionCallErrorExecutionError]]):
    pass




"""Shows gas profile. More info [here](https://near.github.io/nearcore/architecture/gas/gas_profile.html?highlight=WASM_HOST_COST#example-transaction-gas-profile)."""

from pydantic import BaseModel


class CostGasUsed(BaseModel):
    cost: str
    # Either ACTION_COST or WASM_HOST_COST.
    cost_category: str
    gas_used: str



from near_jsonrpc_models.internal_error import InternalError
from near_jsonrpc_models.rpc_request_validation_error_kind import RpcRequestValidationErrorKind
from near_jsonrpc_models.rpc_view_gas_key_list_error import RpcViewGasKeyListError
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class ErrorWrapperForRpcViewGasKeyListErrorRequestValidationError(BaseModel):
    cause: RpcRequestValidationErrorKind
    name: Literal['REQUEST_VALIDATION_ERROR']

class ErrorWrapperForRpcViewGasKeyListErrorHandlerError(BaseModel):
    cause: RpcViewGasKeyListError
    name: Literal['HANDLER_ERROR']

class ErrorWrapperForRpcViewGasKeyListErrorInternalError(BaseModel):
    cause: InternalError
    name: Literal['INTERNAL_ERROR']

class ErrorWrapperForRpcViewGasKeyListError(RootModel[Union[ErrorWrapperForRpcViewGasKeyListErrorRequestValidationError, ErrorWrapperForRpcViewGasKeyListErrorHandlerError, ErrorWrapperForRpcViewGasKeyListErrorInternalError]]):
    pass




"""Epoch identifier -- wrapped hash, to make it easier to distinguish.
EpochId of epoch T is the hash of last block in T-2
EpochId of first two epochs is 0"""

from near_jsonrpc_models.crypto_hash import CryptoHash


EpochId = CryptoHash



"""Lists access keys"""

from near_jsonrpc_models.access_key_info_view import AccessKeyInfoView
from near_jsonrpc_models.crypto_hash import CryptoHash
from pydantic import BaseModel
from pydantic import conint
from typing import List


class RpcViewAccessKeyListResponse(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    keys: List[AccessKeyInfoView]



from near_jsonrpc_models.deterministic_account_state_init_v1 import DeterministicAccountStateInitV1
from near_jsonrpc_models.strict_model import StrictBaseModel
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class DeterministicAccountStateInitV1Option(StrictBaseModel):
    V1: DeterministicAccountStateInitV1

class DeterministicAccountStateInit(RootModel[Union[DeterministicAccountStateInitV1Option]]):
    pass




"""Config for the Chunk Distribution Network feature.
This allows nodes to push and pull chunks from a central stream.
The two benefits of this approach are: (1) less request/response traffic
on the peer-to-peer network and (2) lower latency for RPC nodes indexing the chain."""

from near_jsonrpc_models.chunk_distribution_uris import ChunkDistributionUris
from pydantic import BaseModel


class ChunkDistributionNetworkConfig(BaseModel):
    enabled: bool = None
    uris: ChunkDistributionUris = None



"""AccountData is a piece of global state that a validator
signs and broadcasts to the network.

It is essentially the data that a validator wants to share with the network.
All the nodes in the network are collecting the account data
broadcasted by the validators.
Since the number of the validators is bounded and their
identity is known (and the maximal size of allowed AccountData is bounded)
the global state that is distributed in the form of AccountData is bounded
as well.
Find more information in the docs [here](https://github.com/near/nearcore/blob/560f7fc8f4b3106e0d5d46050688610b1f104ac6/chain/client/src/client.rs#L2232)"""

from near_jsonrpc_models.public_key import PublicKey
from near_jsonrpc_models.tier1proxy_view import Tier1ProxyView
from pydantic import BaseModel
from typing import List


class AccountDataView(BaseModel):
    # Account key of the validator signing this AccountData.
    account_key: PublicKey
    # ID of the node that handles the account key (aka validator key).
    peer_id: PublicKey
    # Proxy nodes that are directly connected to the validator node
    # (this list may include the validator node itself).
    # TIER1 nodes should connect to one of the proxies to sent TIER1
    # messages to the validator.
    proxies: List[Tier1ProxyView]
    # UTC timestamp of when the AccountData has been signed.
    timestamp: str



from near_jsonrpc_models.error_wrapper_for_rpc_protocol_config_error import ErrorWrapperForRpcProtocolConfigError
from near_jsonrpc_models.rpc_protocol_config_response import RpcProtocolConfigResponse
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class JsonRpcResponseForRpcProtocolConfigResponseAndRpcProtocolConfigErrorResult(BaseModel):
    id: str
    jsonrpc: str
    result: RpcProtocolConfigResponse

class JsonRpcResponseForRpcProtocolConfigResponseAndRpcProtocolConfigErrorError(BaseModel):
    id: str
    jsonrpc: str
    error: ErrorWrapperForRpcProtocolConfigError

class JsonRpcResponseForRpcProtocolConfigResponseAndRpcProtocolConfigError(RootModel[Union[JsonRpcResponseForRpcProtocolConfigResponseAndRpcProtocolConfigErrorResult, JsonRpcResponseForRpcProtocolConfigResponseAndRpcProtocolConfigErrorError]]):
    pass




"""Grants limited permission to make transactions with FunctionCallActions
The permission can limit the allowed balance to be spent on the prepaid gas.
It also restrict the account ID of the receiver for this function call.
It also can restrict the method name for the allowed function calls."""

from near_jsonrpc_models.near_token import NearToken
from pydantic import BaseModel
from typing import List


class FunctionCallPermission(BaseModel):
    # Allowance is a balance limit to use by this access key to pay for function call gas and
    # transaction fees. When this access key is used, both account balance and the allowance is
    # decreased by the same value.
    # `None` means unlimited allowance.
    # NOTE: To change or increase the allowance, the old access key needs to be deleted and a new
    # access key should be created.
    allowance: NearToken | None = None
    # A list of method names that can be used. The access key only allows transactions with the
    # function call of one of the given method names.
    # Empty list means any method name can be used.
    method_names: List[str]
    # The access key only allows transactions with the given receiver's account id.
    receiver_id: str



from setuptools import setup, find_packages
import os

PACKAGE_VERSION = os.getenv("PACKAGE_VERSION", "0.1.0")

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="near-jsonrpc-client",
    version=PACKAGE_VERSION,
    description="A typed Python client for the NEAR JSON-RPC API with Pydantic models and async HTTP support",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(include=["near_jsonrpc_client*", "near_jsonrpc_models*"]),
    install_requires=[
        "httpx>=0.24",
        "pydantic>=2.0",
    ],
    python_requires=">=3.9"
)



"""An action that adds key with public key associated"""

from near_jsonrpc_models.access_key import AccessKey
from near_jsonrpc_models.public_key import PublicKey
from pydantic import BaseModel


class AddKeyAction(BaseModel):
    # An access key with the permission
    access_key: AccessKey
    # A public key which will be associated with an access_key
    public_key: PublicKey



from near_jsonrpc_models.error_wrapper_for_rpc_gas_price_error import ErrorWrapperForRpcGasPriceError
from near_jsonrpc_models.rpc_gas_price_response import RpcGasPriceResponse
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class JsonRpcResponseForRpcGasPriceResponseAndRpcGasPriceErrorResult(BaseModel):
    id: str
    jsonrpc: str
    result: RpcGasPriceResponse

class JsonRpcResponseForRpcGasPriceResponseAndRpcGasPriceErrorError(BaseModel):
    id: str
    jsonrpc: str
    error: ErrorWrapperForRpcGasPriceError

class JsonRpcResponseForRpcGasPriceResponseAndRpcGasPriceError(RootModel[Union[JsonRpcResponseForRpcGasPriceResponseAndRpcGasPriceErrorResult, JsonRpcResponseForRpcGasPriceResponseAndRpcGasPriceErrorError]]):
    pass




from near_jsonrpc_models.error_wrapper_for_rpc_chunk_error import ErrorWrapperForRpcChunkError
from near_jsonrpc_models.rpc_congestion_level_response import RpcCongestionLevelResponse
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class JsonRpcResponseForRpcCongestionLevelResponseAndRpcChunkErrorResult(BaseModel):
    id: str
    jsonrpc: str
    result: RpcCongestionLevelResponse

class JsonRpcResponseForRpcCongestionLevelResponseAndRpcChunkErrorError(BaseModel):
    id: str
    jsonrpc: str
    error: ErrorWrapperForRpcChunkError

class JsonRpcResponseForRpcCongestionLevelResponseAndRpcChunkError(RootModel[Union[JsonRpcResponseForRpcCongestionLevelResponseAndRpcChunkErrorResult, JsonRpcResponseForRpcCongestionLevelResponseAndRpcChunkErrorError]]):
    pass




from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.block_reference import BlockReference
from near_jsonrpc_models.crypto_hash import CryptoHash
from pydantic import BaseModel
from pydantic import RootModel
from pydantic import conint
from typing import Literal
from typing import Union


class RpcViewAccessKeyListErrorUnknownBlockInfo(BaseModel):
    block_reference: BlockReference

class RpcViewAccessKeyListErrorUnknownBlock(BaseModel):
    info: RpcViewAccessKeyListErrorUnknownBlockInfo
    name: Literal['UNKNOWN_BLOCK']

class RpcViewAccessKeyListErrorInvalidAccountInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    requested_account_id: AccountId

class RpcViewAccessKeyListErrorInvalidAccount(BaseModel):
    info: RpcViewAccessKeyListErrorInvalidAccountInfo
    name: Literal['INVALID_ACCOUNT']

class RpcViewAccessKeyListErrorUnknownAccountInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    requested_account_id: AccountId

class RpcViewAccessKeyListErrorUnknownAccount(BaseModel):
    info: RpcViewAccessKeyListErrorUnknownAccountInfo
    name: Literal['UNKNOWN_ACCOUNT']

class RpcViewAccessKeyListErrorInternalErrorInfo(BaseModel):
    error_message: str

class RpcViewAccessKeyListErrorInternalError(BaseModel):
    info: RpcViewAccessKeyListErrorInternalErrorInfo
    name: Literal['INTERNAL_ERROR']

class RpcViewAccessKeyListError(RootModel[Union[RpcViewAccessKeyListErrorUnknownBlock, RpcViewAccessKeyListErrorInvalidAccount, RpcViewAccessKeyListErrorUnknownAccount, RpcViewAccessKeyListErrorInternalError]]):
    pass




from near_jsonrpc_models.internal_error import InternalError
from near_jsonrpc_models.rpc_chunk_error import RpcChunkError
from near_jsonrpc_models.rpc_request_validation_error_kind import RpcRequestValidationErrorKind
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class ErrorWrapperForRpcChunkErrorRequestValidationError(BaseModel):
    cause: RpcRequestValidationErrorKind
    name: Literal['REQUEST_VALIDATION_ERROR']

class ErrorWrapperForRpcChunkErrorHandlerError(BaseModel):
    cause: RpcChunkError
    name: Literal['HANDLER_ERROR']

class ErrorWrapperForRpcChunkErrorInternalError(BaseModel):
    cause: InternalError
    name: Literal['INTERNAL_ERROR']

class ErrorWrapperForRpcChunkError(RootModel[Union[ErrorWrapperForRpcChunkErrorRequestValidationError, ErrorWrapperForRpcChunkErrorHandlerError, ErrorWrapperForRpcChunkErrorInternalError]]):
    pass




"""Describes the cost of creating a specific action, `Action`. Includes all variants."""

from near_jsonrpc_models.access_key_creation_config_view import AccessKeyCreationConfigView
from near_jsonrpc_models.fee import Fee
from pydantic import BaseModel


class ActionCreationConfigView(BaseModel):
    # Base cost of adding a key.
    add_key_cost: AccessKeyCreationConfigView = None
    # Base cost of creating an account.
    create_account_cost: Fee = None
    # Base cost for processing a delegate action.
    # 
    # This is on top of the costs for the actions inside the delegate action.
    delegate_cost: Fee = None
    # Base cost of deleting an account.
    delete_account_cost: Fee = None
    # Base cost of deleting a key.
    delete_key_cost: Fee = None
    # Base cost of deploying a contract.
    deploy_contract_cost: Fee = None
    # Cost per byte of deploying a contract.
    deploy_contract_cost_per_byte: Fee = None
    # Base cost of calling a function.
    function_call_cost: Fee = None
    # Cost per byte of method name and arguments of calling a function.
    function_call_cost_per_byte: Fee = None
    # Base cost of staking.
    stake_cost: Fee = None
    # Base cost of making a transfer.
    transfer_cost: Fee = None



from near_jsonrpc_models.crypto_hash import CryptoHash
from near_jsonrpc_models.state_change_kind_view import StateChangeKindView
from pydantic import BaseModel
from typing import List


class RpcStateChangesInBlockByTypeResponse(BaseModel):
    block_hash: CryptoHash
    changes: List[StateChangeKindView]



"""Typed view of ExtCostsConfig to preserve JSON output field names in protocol
config RPC output."""

from near_jsonrpc_models.near_gas import NearGas
from pydantic import BaseModel


class ExtCostsConfigView(BaseModel):
    # Base cost for multiexp
    alt_bn128_g1_multiexp_base: NearGas = None
    # Per element cost for multiexp
    alt_bn128_g1_multiexp_element: NearGas = None
    # Base cost for sum
    alt_bn128_g1_sum_base: NearGas = None
    # Per element cost for sum
    alt_bn128_g1_sum_element: NearGas = None
    # Base cost for pairing check
    alt_bn128_pairing_check_base: NearGas = None
    # Per element cost for pairing check
    alt_bn128_pairing_check_element: NearGas = None
    # Base cost for calling a host function.
    base: NearGas = None
    bls12381_g1_multiexp_base: NearGas = None
    bls12381_g1_multiexp_element: NearGas = None
    bls12381_g2_multiexp_base: NearGas = None
    bls12381_g2_multiexp_element: NearGas = None
    bls12381_map_fp2_to_g2_base: NearGas = None
    bls12381_map_fp2_to_g2_element: NearGas = None
    bls12381_map_fp_to_g1_base: NearGas = None
    bls12381_map_fp_to_g1_element: NearGas = None
    bls12381_p1_decompress_base: NearGas = None
    bls12381_p1_decompress_element: NearGas = None
    bls12381_p1_sum_base: NearGas = None
    bls12381_p1_sum_element: NearGas = None
    bls12381_p2_decompress_base: NearGas = None
    bls12381_p2_decompress_element: NearGas = None
    bls12381_p2_sum_base: NearGas = None
    bls12381_p2_sum_element: NearGas = None
    bls12381_pairing_base: NearGas = None
    bls12381_pairing_element: NearGas = None
    contract_compile_base: NearGas = None
    contract_compile_bytes: NearGas = None
    # Base cost of loading a pre-compiled contract
    contract_loading_base: NearGas = None
    # Cost per byte of loading a pre-compiled contract
    contract_loading_bytes: NearGas = None
    # Cost of calling ecrecover
    ecrecover_base: NearGas = None
    # Cost of getting ed25519 base
    ed25519_verify_base: NearGas = None
    # Cost of getting ed25519 per byte
    ed25519_verify_byte: NearGas = None
    # Cost of getting sha256 base
    keccak256_base: NearGas = None
    # Cost of getting sha256 per byte
    keccak256_byte: NearGas = None
    # Cost of getting sha256 base
    keccak512_base: NearGas = None
    # Cost of getting sha256 per byte
    keccak512_byte: NearGas = None
    # Cost for calling logging.
    log_base: NearGas = None
    # Cost for logging per byte
    log_byte: NearGas = None
    # Cost for calling `promise_and`
    promise_and_base: NearGas = None
    # Cost for calling `promise_and` for each promise
    promise_and_per_promise: NearGas = None
    # Cost for calling `promise_return`
    promise_return: NearGas = None
    # Cost for reading trie node from memory
    read_cached_trie_node: NearGas = None
    # Base cost for guest memory read
    read_memory_base: NearGas = None
    # Cost for guest memory read
    read_memory_byte: NearGas = None
    # Base cost for reading from register
    read_register_base: NearGas = None
    # Cost for reading byte from register
    read_register_byte: NearGas = None
    # Cost of getting ripemd160 base
    ripemd160_base: NearGas = None
    # Cost of getting ripemd160 per message block
    ripemd160_block: NearGas = None
    # Cost of getting sha256 base
    sha256_base: NearGas = None
    # Cost of getting sha256 per byte
    sha256_byte: NearGas = None
    # Storage trie check for key existence cost base
    storage_has_key_base: NearGas = None
    # Storage trie check for key existence per key byte
    storage_has_key_byte: NearGas = None
    # Create trie range iterator cost per byte of from key.
    storage_iter_create_from_byte: NearGas = None
    # Create trie prefix iterator cost base
    storage_iter_create_prefix_base: NearGas = None
    # Create trie prefix iterator cost per byte.
    storage_iter_create_prefix_byte: NearGas = None
    # Create trie range iterator cost base
    storage_iter_create_range_base: NearGas = None
    # Create trie range iterator cost per byte of to key.
    storage_iter_create_to_byte: NearGas = None
    # Trie iterator per key base cost
    storage_iter_next_base: NearGas = None
    # Trie iterator next key byte cost
    storage_iter_next_key_byte: NearGas = None
    # Trie iterator next key byte cost
    storage_iter_next_value_byte: NearGas = None
    # Storage trie read key overhead base cost, when doing large reads
    storage_large_read_overhead_base: NearGas = None
    # Storage trie read key overhead  per-byte cost, when doing large reads
    storage_large_read_overhead_byte: NearGas = None
    # Storage trie read key base cost
    storage_read_base: NearGas = None
    # Storage trie read key per byte cost
    storage_read_key_byte: NearGas = None
    # Storage trie read value cost per byte cost
    storage_read_value_byte: NearGas = None
    # Remove key from trie base cost
    storage_remove_base: NearGas = None
    # Remove key from trie per byte cost
    storage_remove_key_byte: NearGas = None
    # Remove key from trie ret value byte cost
    storage_remove_ret_value_byte: NearGas = None
    # Storage trie write key base cost
    storage_write_base: NearGas = None
    # Storage trie write cost per byte of evicted value.
    storage_write_evicted_byte: NearGas = None
    # Storage trie write key per byte cost
    storage_write_key_byte: NearGas = None
    # Storage trie write value per byte cost
    storage_write_value_byte: NearGas = None
    # Cost per reading trie node from DB
    touching_trie_node: NearGas = None
    # Base cost of decoding utf16. It's used for `log_utf16`.
    utf16_decoding_base: NearGas = None
    # Cost per byte of decoding utf16. It's used for `log_utf16`.
    utf16_decoding_byte: NearGas = None
    # Base cost of decoding utf8. It's used for `log_utf8` and `panic_utf8`.
    utf8_decoding_base: NearGas = None
    # Cost per byte of decoding utf8. It's used for `log_utf8` and `panic_utf8`.
    utf8_decoding_byte: NearGas = None
    # Cost of calling `validator_stake`.
    validator_stake_base: NearGas = None
    # Cost of calling `validator_total_stake`.
    validator_total_stake_base: NearGas = None
    # Base cost for guest memory write
    write_memory_base: NearGas = None
    # Cost for guest memory write per byte
    write_memory_byte: NearGas = None
    # Base cost for writing into register
    write_register_base: NearGas = None
    # Cost for writing byte into register
    write_register_byte: NearGas = None
    # Base cost for creating a yield promise.
    yield_create_base: NearGas = None
    # Per byte cost of arguments and method name.
    yield_create_byte: NearGas = None
    # Base cost for resuming a yield receipt.
    yield_resume_base: NearGas = None
    # Per byte cost of resume payload.
    yield_resume_byte: NearGas = None



from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class RpcSplitStorageInfoErrorInternalErrorInfo(BaseModel):
    error_message: str

class RpcSplitStorageInfoErrorInternalError(BaseModel):
    info: RpcSplitStorageInfoErrorInternalErrorInfo
    name: Literal['INTERNAL_ERROR']

class RpcSplitStorageInfoError(RootModel[Union[RpcSplitStorageInfoErrorInternalError]]):
    pass




"""A kind of a trap happened during execution of a binaryUnreachable: An `unreachable` opcode was executed.IncorrectCallIndirectSignature: Call indirect incorrect signature trap.MemoryOutOfBounds: Memory out of bounds trap.CallIndirectOOB: Call indirect out of bounds trap.IllegalArithmetic: An arithmetic exception, e.g. divided by zero.MisalignedAtomicAccess: Misaligned atomic access trap.IndirectCallToNull: Indirect call to null.StackOverflow: Stack overflow.GenericTrap: Generic trap."""

from pydantic import RootModel
from typing import Literal


class WasmTrap(RootModel[Literal['Unreachable', 'IncorrectCallIndirectSignature', 'MemoryOutOfBounds', 'CallIndirectOOB', 'IllegalArithmetic', 'MisalignedAtomicAccess', 'IndirectCallToNull', 'StackOverflow', 'GenericTrap']]):
    pass




from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.block_reference import BlockReference
from near_jsonrpc_models.crypto_hash import CryptoHash
from pydantic import BaseModel
from pydantic import RootModel
from pydantic import conint
from typing import Literal
from typing import Union


class RpcViewCodeErrorUnknownBlockInfo(BaseModel):
    block_reference: BlockReference

class RpcViewCodeErrorUnknownBlock(BaseModel):
    info: RpcViewCodeErrorUnknownBlockInfo
    name: Literal['UNKNOWN_BLOCK']

class RpcViewCodeErrorInvalidAccountInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    requested_account_id: AccountId

class RpcViewCodeErrorInvalidAccount(BaseModel):
    info: RpcViewCodeErrorInvalidAccountInfo
    name: Literal['INVALID_ACCOUNT']

class RpcViewCodeErrorUnknownAccountInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    requested_account_id: AccountId

class RpcViewCodeErrorUnknownAccount(BaseModel):
    info: RpcViewCodeErrorUnknownAccountInfo
    name: Literal['UNKNOWN_ACCOUNT']

class RpcViewCodeErrorNoContractCodeInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    contract_account_id: AccountId

class RpcViewCodeErrorNoContractCode(BaseModel):
    info: RpcViewCodeErrorNoContractCodeInfo
    name: Literal['NO_CONTRACT_CODE']

class RpcViewCodeErrorInternalErrorInfo(BaseModel):
    error_message: str

class RpcViewCodeErrorInternalError(BaseModel):
    info: RpcViewCodeErrorInternalErrorInfo
    name: Literal['INTERNAL_ERROR']

class RpcViewCodeError(RootModel[Union[RpcViewCodeErrorUnknownBlock, RpcViewCodeErrorInvalidAccount, RpcViewCodeErrorUnknownAccount, RpcViewCodeErrorNoContractCode, RpcViewCodeErrorInternalError]]):
    pass




from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class RpcRequestValidationErrorKindMethodNotFoundInfo(BaseModel):
    method_name: str

class RpcRequestValidationErrorKindMethodNotFound(BaseModel):
    info: RpcRequestValidationErrorKindMethodNotFoundInfo
    name: Literal['METHOD_NOT_FOUND']

class RpcRequestValidationErrorKindParseErrorInfo(BaseModel):
    error_message: str

class RpcRequestValidationErrorKindParseError(BaseModel):
    info: RpcRequestValidationErrorKindParseErrorInfo
    name: Literal['PARSE_ERROR']

class RpcRequestValidationErrorKind(RootModel[Union[RpcRequestValidationErrorKindMethodNotFound, RpcRequestValidationErrorKindParseError]]):
    pass




"""Resulting state values for a view state query request"""

from near_jsonrpc_models.state_item import StateItem
from pydantic import BaseModel
from typing import List


class ViewStateResult(BaseModel):
    proof: List[str] = None
    values: List[StateItem]



from near_jsonrpc_models.rpc_light_client_next_block_request import RpcLightClientNextBlockRequest
from pydantic import BaseModel
from typing import Literal


class JsonRpcRequestForNextLightClientBlock(BaseModel):
    id: str
    jsonrpc: str
    method: Literal['next_light_client_block']
    params: RpcLightClientNextBlockRequest



from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.crypto_hash import CryptoHash
from near_jsonrpc_models.receipt_enum_view import ReceiptEnumView
from pydantic import BaseModel
from pydantic import conint


class RpcReceiptResponse(BaseModel):
    predecessor_id: AccountId
    # Deprecated, retained for backward compatibility.
    priority: conint(ge=0, le=18446744073709551615) = 0
    receipt: ReceiptEnumView
    receipt_id: CryptoHash
    receiver_id: AccountId



"""Item of the state, key and value are serialized in base64 and proof for inclusion of given state item."""

from near_jsonrpc_models.store_key import StoreKey
from near_jsonrpc_models.store_value import StoreValue
from pydantic import BaseModel


class StateItem(BaseModel):
    key: StoreKey
    value: StoreValue



from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.block_reference import BlockReference
from near_jsonrpc_models.crypto_hash import CryptoHash
from near_jsonrpc_models.public_key import PublicKey
from pydantic import BaseModel
from pydantic import RootModel
from pydantic import conint
from typing import Literal
from typing import Union


class RpcViewAccessKeyErrorUnknownBlockInfo(BaseModel):
    block_reference: BlockReference

class RpcViewAccessKeyErrorUnknownBlock(BaseModel):
    info: RpcViewAccessKeyErrorUnknownBlockInfo
    name: Literal['UNKNOWN_BLOCK']

class RpcViewAccessKeyErrorInvalidAccountInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    requested_account_id: AccountId

class RpcViewAccessKeyErrorInvalidAccount(BaseModel):
    info: RpcViewAccessKeyErrorInvalidAccountInfo
    name: Literal['INVALID_ACCOUNT']

class RpcViewAccessKeyErrorUnknownAccountInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    requested_account_id: AccountId

class RpcViewAccessKeyErrorUnknownAccount(BaseModel):
    info: RpcViewAccessKeyErrorUnknownAccountInfo
    name: Literal['UNKNOWN_ACCOUNT']

class RpcViewAccessKeyErrorUnknownAccessKeyInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    public_key: PublicKey

class RpcViewAccessKeyErrorUnknownAccessKey(BaseModel):
    info: RpcViewAccessKeyErrorUnknownAccessKeyInfo
    name: Literal['UNKNOWN_ACCESS_KEY']

class RpcViewAccessKeyErrorInternalErrorInfo(BaseModel):
    error_message: str

class RpcViewAccessKeyErrorInternalError(BaseModel):
    info: RpcViewAccessKeyErrorInternalErrorInfo
    name: Literal['INTERNAL_ERROR']

class RpcViewAccessKeyError(RootModel[Union[RpcViewAccessKeyErrorUnknownBlock, RpcViewAccessKeyErrorInvalidAccount, RpcViewAccessKeyErrorUnknownAccount, RpcViewAccessKeyErrorUnknownAccessKey, RpcViewAccessKeyErrorInternalError]]):
    pass




"""Transfer NEAR to a gas key's balance"""

from near_jsonrpc_models.near_token import NearToken
from near_jsonrpc_models.public_key import PublicKey
from pydantic import BaseModel


class TransferToGasKeyAction(BaseModel):
    # Amount of NEAR to transfer to the gas key
    deposit: NearToken
    # The public key of the gas key to fund
    public_key: PublicKey



"""Describes the error for validating a receipt."""

from near_jsonrpc_models.actions_validation_error import ActionsValidationError
from near_jsonrpc_models.strict_model import StrictBaseModel
from pydantic import BaseModel
from pydantic import RootModel
from pydantic import conint
from typing import Union


class ReceiptValidationErrorInvalidPredecessorIdPayload(BaseModel):
    account_id: str

class ReceiptValidationErrorInvalidPredecessorId(StrictBaseModel):
    """The `predecessor_id` of a Receipt is not valid."""
    InvalidPredecessorId: ReceiptValidationErrorInvalidPredecessorIdPayload

class ReceiptValidationErrorInvalidReceiverIdPayload(BaseModel):
    account_id: str

class ReceiptValidationErrorInvalidReceiverId(StrictBaseModel):
    """The `receiver_id` of a Receipt is not valid."""
    InvalidReceiverId: ReceiptValidationErrorInvalidReceiverIdPayload

class ReceiptValidationErrorInvalidSignerIdPayload(BaseModel):
    account_id: str

class ReceiptValidationErrorInvalidSignerId(StrictBaseModel):
    """The `signer_id` of an ActionReceipt is not valid."""
    InvalidSignerId: ReceiptValidationErrorInvalidSignerIdPayload

class ReceiptValidationErrorInvalidDataReceiverIdPayload(BaseModel):
    account_id: str

class ReceiptValidationErrorInvalidDataReceiverId(StrictBaseModel):
    """The `receiver_id` of a DataReceiver within an ActionReceipt is not valid."""
    InvalidDataReceiverId: ReceiptValidationErrorInvalidDataReceiverIdPayload

class ReceiptValidationErrorReturnedValueLengthExceededPayload(BaseModel):
    length: conint(ge=0, le=18446744073709551615)
    limit: conint(ge=0, le=18446744073709551615)

class ReceiptValidationErrorReturnedValueLengthExceeded(StrictBaseModel):
    """The length of the returned data exceeded the limit in a DataReceipt."""
    ReturnedValueLengthExceeded: ReceiptValidationErrorReturnedValueLengthExceededPayload

class ReceiptValidationErrorNumberInputDataDependenciesExceededPayload(BaseModel):
    limit: conint(ge=0, le=18446744073709551615)
    number_of_input_data_dependencies: conint(ge=0, le=18446744073709551615)

class ReceiptValidationErrorNumberInputDataDependenciesExceeded(StrictBaseModel):
    """The number of input data dependencies exceeds the limit in an ActionReceipt."""
    NumberInputDataDependenciesExceeded: ReceiptValidationErrorNumberInputDataDependenciesExceededPayload

class ReceiptValidationErrorActionsValidation(StrictBaseModel):
    """An error occurred while validating actions of an ActionReceipt."""
    ActionsValidation: ActionsValidationError

class ReceiptValidationErrorReceiptSizeExceededPayload(BaseModel):
    limit: conint(ge=0, le=18446744073709551615)
    size: conint(ge=0, le=18446744073709551615)

class ReceiptValidationErrorReceiptSizeExceeded(StrictBaseModel):
    """Receipt is bigger than the limit."""
    ReceiptSizeExceeded: ReceiptValidationErrorReceiptSizeExceededPayload

class ReceiptValidationErrorInvalidRefundToPayload(BaseModel):
    account_id: str

class ReceiptValidationErrorInvalidRefundTo(StrictBaseModel):
    """The `refund_to` of an ActionReceipt is not valid."""
    InvalidRefundTo: ReceiptValidationErrorInvalidRefundToPayload

class ReceiptValidationError(RootModel[Union[ReceiptValidationErrorInvalidPredecessorId, ReceiptValidationErrorInvalidReceiverId, ReceiptValidationErrorInvalidSignerId, ReceiptValidationErrorInvalidDataReceiverId, ReceiptValidationErrorReturnedValueLengthExceeded, ReceiptValidationErrorNumberInputDataDependenciesExceeded, ReceiptValidationErrorActionsValidation, ReceiptValidationErrorReceiptSizeExceeded, ReceiptValidationErrorInvalidRefundTo]]):
    pass

